@@ -13,6 +13,8 @@ import json
 import pandas as pd
 import pickle
 from datetime import datetime as dt
+
+from napoleontoolbox.connector import shifting_utility
 # Local packages
 
 __all__ = ['NaPoleonXConnector']
@@ -53,6 +55,25 @@ def request_day_data_paquet(url, me_ts, ssj):
         print('no data')
     return dataframe
 
+def fetch_delayed_crypto_daily_data(frequence = 'daily', ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance', delay = 0):
+    assert delay>0
+    hourly_crypto_df = fetch_crypto_hourly_data(ssj=ssj,local_root_directory=local_root_directory,
+                                                                   refetch_all=refetch_all,
+                                                                   daily_crypto_starting_day=daily_crypto_starting_day,
+                                                                   daily_crypto_ending_day=daily_crypto_ending_day)
+
+    daily_crypto_df = shifting_utility.shift_daily_crypto_compare_signal(hourly_data = hourly_crypto_df, ssj=ssj, local_root_directory=local_root_directory,
+                                                                     shift=delay, starting_date=daily_crypto_starting_day,
+                                                                     running_date=daily_crypto_ending_day, frequence='daily')
+
+    freqly_pkl_file_name_suffix = f'_{frequence}_returns.pkl'
+    dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
+    saving_return_path = f'{local_root_directory}{ssj}_{dates_stub}_{delay}_{freqly_pkl_file_name_suffix}'
+    daily_crypto_df.to_pickle(saving_return_path)
+    return daily_crypto_df
+
+
+
 def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+daily_return_pkl_filename_suffix
