@@ -57,7 +57,7 @@ def daily_bc_apply_standard_mean_discretization(signals_df=None, s=21, method ='
     return y_pred_discretized
 
 class AbstractRunner(ABC):
-    def __init__(self, calibration_starting_date = None,  calibration_running_date = None, starting_date = None,  running_date = None,  drop_token=None, dropbox_backup = True, underlying = None, frequence='daily', selected_algo='',algo='' ,freqly_return_pkl_filename_suffix='freqly_candels.pkl',aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None, daily_ia_lookback_window=21):
+    def __init__(self, calibration_starting_date = None,  calibration_running_date = None, starting_date = None,  running_date = None,  drop_token=None, dropbox_backup = True, underlying = None, frequence='daily', selected_algo='',algo='' ,freqly_return_pkl_filename_suffix='freqly_candels.pkl',aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None, daily_ia_lookback_window=21, delay = 0):
         super().__init__()
         self.starting_date = starting_date
         self.running_date = running_date
@@ -72,13 +72,21 @@ class AbstractRunner(ABC):
         self.frequence=frequence
         self.algo=algo
         self.selected_algo=selected_algo
+        self.delay = delay
 
         self.calibrating_dates_stub = self.calibration_starting_date.strftime('%d_%b_%Y') + '_' + self.calibration_running_date.strftime('%d_%b_%Y')
         self.dates_stub = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y')
 
-        self.list_pkl_file_name = self.calibrating_dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
-        self.aggregated_pkl_file_name = self.dates_stub +'_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
-        self.aggregated_pkl_mapping_file_name = self.dates_stub +'_'+ self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
+        if self.frequence == 'daily':
+            self.list_pkl_file_name = self.calibrating_dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
+            self.aggregated_pkl_file_name = self.dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + '_' + str(
+                self.delay) + self.aggregated_pkl_file_suffix
+            self.aggregated_pkl_mapping_file_name = self.dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + '_' + str(
+                self.delay) + self.aggregated_pkl_mapping_file_suffix
+        else:
+            self.list_pkl_file_name = self.calibrating_dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
+            self.aggregated_pkl_file_name = self.dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
+            self.aggregated_pkl_mapping_file_name = self.dates_stub + '_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
 
         self.local_root_directory=local_root_directory
         self.user=user
@@ -99,7 +107,10 @@ class AbstractRunner(ABC):
 
         self.recompute_all = recompute_all
         self.db_path_suffix = db_path_suffix
-        self.db_path_name = launcher_utility.get_database_name(user, frequence, underlying, algo, starting_date, running_date, db_path_suffix)
+        if self.frequence == 'daily':
+            self.db_path_name = launcher_utility.get_daily_database_name(user, frequence, underlying, algo, starting_date, running_date, delay, db_path_suffix)
+        else:
+            self.db_path_name = launcher_utility.get_database_name(user, frequence, underlying, algo, starting_date, running_date, db_path_suffix)
 
         # if not self.recompute_all:
         #     saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
@@ -114,17 +125,16 @@ class AbstractRunner(ABC):
                                                                  db_path_name=self.db_path_name)
         self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
         self.daily_ia_lookback_window = daily_ia_lookback_window
+
+
         print('done')
 
     @abstractmethod
     def runTrial(self,saver):
         pass
 
-
 class AggregatingSignalRunner(AbstractRunner):
-
     def backup_to_dropbox(self):
-
         local_root_directory = Path(self.local_root_directory)
         aggregated_csv_file_name = self.aggregated_pkl_file_name.replace('pkl', 'csv')
         aggregated_csv_mapping_file_name = self.aggregated_pkl_mapping_file_name.replace('pkl', 'csv')
