@@ -773,3 +773,54 @@ def find_best_three_states_discretization_lo(y_pred, y, seed = 42, number_per_ye
     upper_threshold = np.quantile(y_pred, upper_quantile_threshold)
     return lower_quantile_threshold, upper_quantile_threshold, lower_threshold, upper_threshold, sharpe_strat, sharpe_under
 
+def transform_daily_shifted_to_hourly(drop_token=None,local_root_directory=None,user='npam', ssj = 'BTC', db_path_name_prefix=None, db_path_name_suffix = None, hourly_return_pickle_file=None, transaction_cost=True, number_of_delta = 24):
+    all_signals_df = pd.DataFrame()
+    all__parallel_results_df = pd.DataFrame()
+
+    ### Reconstitute Signals
+
+    for delta in range(number_of_delta):
+        print(delta)
+        if delta >0:
+            db_path_name = db_path_name_prefix + '_shifted_' + str(delta) + db_path_name_suffix
+        else:
+            db_path_name = db_path_name_prefix + db_path_name_suffix
+        print(db_path_name)
+        saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
+                                                                 local_root_directory=local_root_directory, user=user,
+                                                                 db_path_name=db_path_name)
+        _parallel_results_df, signals_df = saver.analyzeAllRunResults(jsonized_output=False)
+        try:
+            _parallel_results_df = _parallel_results_df.astype(float)
+        except:
+            continue
+        _parallel_results_df.index += pd.DateOffset(hours=delta)
+        signals_df.index += pd.DateOffset(hours=delta)
+
+        if all_signals_df.empty:
+            all_signals_df = signals_df
+        else:
+            all_signals_df = pd.concat([all_signals_df, signals_df])
+            all_signals_df = all_signals_df.sort_index(inplace=False)
+
+    ### Reconstitute Perfs
+
+    return_df = pd.read_pickle(local_root_directory + hourly_return_pickle_file)
+    all_signals_df = pd.merge(all_signals_df, return_df[['close']], left_index=True, right_index=True)
+    for column in all_signals_df.columns:
+        if column != 'close':
+            signal_to_check = all_signals_df[[column, 'close']]
+            signal_to_check = signal_to_check.rename(columns={column: "signal"}, errors="raise")
+            data, average_turn_over = signal_utility.reconstitute_signal_perf(signal_to_check, transaction_cost=transaction_cost)
+            print(column, average_turn_over, 'turn over')
+            if all__parallel_results_df.empty:
+                all__parallel_results_df = data[['reconstituted_perf']]
+                all__parallel_results_df.columns = [column]
+            else:
+                all__parallel_results_df[column] = data['reconstituted_perf']
+
+
+    all_signals_df.to_pickle(local_root_directory + ssj+'_shifted_signals_df.pickle')
+    all__parallel_results_df.to_pickle(local_root_directory + ssj+'_shifted_parallel_results_df.pickle')
+    return all_signals_df, all__parallel_results_df
+
